clear all;
close all;

%% 300 K

load('300K_NMOS.mat')

%NMOS
figure(1)
hold on
plot(Vdd_meas(1,:), Vref(1,:))
plot(Vdd_meas(2,:), Vref(2,:))
plot(Vdd_meas(6,:), Vref(6,:))
hold off
title('NMOS Line Regulation (300 K)')
ylabel('Vref [V]')
xlabel('Vdd [V]')
xlim([0.65 1.15])
grid on
legend('PSR Architecture', 'PSR Architecture', 'Basic Architecture')

%Compute approximation
start_ind = 396;

p300 = NaN*zeros(34,2);

%Perform the fit for NMOS
for j=[1, 2, 6]
    p300(j,:) = polyfit(Vdd_meas(j,start_ind:end), Vref(j,start_ind:end),1);
end

%Axis for polyval
VddN = [Vdd_meas(1,start_ind), Vdd_meas(1,end)];

%NMOS
figure(2)
hold on

plot(Vdd_meas(1,1:end), Vref(1,1:end))
plot(Vdd_meas(2,1:end), Vref(2,1:end))
plot(Vdd_meas(6,1:end), Vref(6,1:end))

plot(VddN, polyval(p300(1,:), VddN))
plot(VddN, polyval(p300(2,:), VddN))
plot(VddN, polyval(p300(6,:), VddN))

hold off
title('NMOS Line Regulation (300 K)')
ylabel('Vref [V]')
xlabel('Vdd [V]')
xlim([0.95 1.15])
grid on
legend('PSR, measured', 'PSR, measured', 'Basic, measured', 'PSR, linear fit', 'PSR, linear fit', 'Basic, linear fit')




load('300K_DTMOS.mat')


%DTMOS
figure(3)
hold on
plot(Vdd_meas(13,:), Vdd_meas(13,:)-Vref(13,:))
plot(Vdd_meas(17,:), Vdd_meas(17,:)-Vref(17,:))
plot(Vdd_meas(18,:), Vdd_meas(18,:)-Vref(18,:))
hold off
title('DTMOS Line Regulation (300 K)')
ylabel('Vref [V]')
xlabel('Vdd [V]')
xlim([0.65 1.15])
grid on
legend('PSR Architecture', 'PSR Architecture', 'Basic Architecture')


%Perform the fit for DTMOS
for j=[13, 17, 18]
    p300(j,:) = polyfit(Vdd_meas(j,start_ind:end), Vdd_meas(j,start_ind:end)-Vref(j,start_ind:end),1);
end

VddDT = [Vdd_meas(13,start_ind), Vdd_meas(13,end)];

%DTMOS
figure(4)
hold on

plot(Vdd_meas(13,1:end), Vdd_meas(13,1:end)-Vref(13,1:end))
plot(Vdd_meas(17,1:end), Vdd_meas(17,1:end)-Vref(17,1:end))
plot(Vdd_meas(18,1:end), Vdd_meas(18,1:end)-Vref(18,1:end))

plot(VddDT, polyval(p300(13,:), VddDT))
plot(VddDT, polyval(p300(17,:), VddDT))
plot(VddDT, polyval(p300(18,:), VddDT))

hold off
title('DTMOS Line Regulation (300 K)')
ylabel('Vref [V]')
xlabel('Vdd [V]')
xlim([0.95 1.15])
grid on
legend('PSR, measured', 'PSR, measured', 'Basic, measured', 'PSR, linear fit', 'PSR, linear fit', 'Basic, linear fit')



load('300K_PMOS.mat')

%PMOS
figure(5)
hold on
plot(Vdd_meas(29,:), Vdd_meas(29,:)-Vref(29,:))
plot(Vdd_meas(30,:), Vdd_meas(30,:)-Vref(30,:))
plot(Vdd_meas(34,:), Vdd_meas(34,:)-Vref(34,:))
hold off
title('PMOS Line Regulation (300 K)')
ylabel('Vref [V]')
xlabel('Vdd [V]')
xlim([0.65 1.15])
grid on
legend('PSR Architecture', 'PSR Architecture', 'Basic Architecture')


%Perform the fit for PMOS
for j=[29, 30, 34]
    p300(j,:) = polyfit(Vdd_meas(j,start_ind:end), Vdd_meas(j,start_ind:end)-Vref(j,start_ind:end),1);
end

VddP = [Vdd_meas(29,start_ind), Vdd_meas(29,end)];

%PMOS
figure(6)
hold on

plot(Vdd_meas(29,1:end), Vdd_meas(29,1:end)-Vref(29,1:end))
plot(Vdd_meas(30,1:end), Vdd_meas(30,1:end)-Vref(30,1:end))
plot(Vdd_meas(34,1:end), Vdd_meas(34,1:end)-Vref(34,1:end))

plot(VddP, polyval(p300(29,:), VddP))
plot(VddP, polyval(p300(30,:), VddP))
plot(VddP, polyval(p300(34,:), VddP))

hold off
title('PMOS Line Regulation (300 K)')
ylabel('Vref [V]')
xlabel('Vdd [V]')
xlim([0.95 1.15])
grid on
legend('PSR, measured', 'PSR, measured', 'Basic, measured', 'PSR, linear fit', 'PSR, linear fit', 'Basic, linear fit')


%% 4 K

close all;

p4 = NaN*zeros(34,2);


load('4K_NMOS.mat')

%NMOS
figure(7)
hold on
plot(Vdd_meas(1,:), Vref(1,:))
plot(Vdd_meas(2,:), Vref(2,:))
plot(Vdd_meas(6,:), Vref(6,:))
hold off
title('NMOS Line Regulation (4 K)')
ylabel('Vref [V]')
xlabel('Vdd [V]')
xlim([0.9 1.15])
ylim([0 0.55])
grid on
legend('PSR Architecture', 'PSR Architecture', 'Basic Architecture')

start_ind = 97;


%----Perfom the fit for the well-behaved curves
%Perform the fit for NMOS
for j=[2, 6]
    p4(j,:) = polyfit(Vdd_meas(j,start_ind:end), Vref(j,start_ind:end),1);
end

%Axis for polyval
VddN4 = [Vdd_meas(1,start_ind), Vdd_meas(1,end)];


%----Perform the fit for the curve with incorrect readings------

%Remove incorrect readings for the NMOS above 1.1 where it did not start up
Vref(1,(Vref(1,:) <= 0.4)) = NaN;

%Store all (including the nans) in separate vector
Vref1_temp = Vref(1,start_ind:end);
Vdd1_temp = Vdd_meas(1,start_ind:end);

%Get indices of nan-values
ind_nan = isnan(Vref1_temp);

%Perform fit on only the non-nan values
p4(1,:) = polyfit(Vdd1_temp(~ind_nan), Vref1_temp(~ind_nan), 1);

%-----

%NMOS
figure(8)
hold on

plot(Vdd_meas(1,1:end), Vref(1,1:end))
plot(Vdd_meas(2,1:end), Vref(2,1:end))
plot(Vdd_meas(6,1:end), Vref(6,1:end))

plot(VddN4, polyval(p4(1,:), VddN4))
plot(VddN4, polyval(p4(2,:), VddN4))
plot(VddN4, polyval(p4(6,:), VddN4))

hold off
title('NMOS Line Regulation (4 K)')
ylabel('Vref [V]')
xlabel('Vdd [V]')
xlim([0.95 1.15])
ylim([0.47 0.5])
grid on
legend('PSR, measured', 'PSR, measured', 'Basic, measured', 'PSR, linear fit', 'PSR, linear fit', 'Basic, linear fit')




load('4K_DTMOS.mat')

%DTMOS
figure(9)
hold on
plot(Vdd_meas(13,:), Vdd_meas(13,:)-Vref(13,:))
plot(Vdd_meas(17,:), Vdd_meas(17,:)-Vref(17,:))
plot(Vdd_meas(18,:), Vdd_meas(18,:)-Vref(18,:))
hold off
title('DTMOS Line Regulation (4 K)')
ylabel('Vref [V]')
xlabel('Vdd [V]')
xlim([0.9 1.15])
ylim([0.3 0.65])
grid on
legend('PSR Architecture', 'PSR Architecture', 'Basic Architecture')


start_ind = 97;

%Perform the fit for DTMOS
for j=[13, 17, 18]
    p4(j,:) = polyfit(Vdd_meas(j,start_ind:end), Vdd_meas(j,start_ind:end)-Vref(j,start_ind:end),1);
end

VddDT4 = [Vdd_meas(13,start_ind), Vdd_meas(13,end)];

%DTMOS
figure(10)
hold on

plot(Vdd_meas(13,1:end), Vdd_meas(13,1:end)-Vref(13,1:end))
plot(Vdd_meas(17,1:end), Vdd_meas(17,1:end)-Vref(17,1:end))
plot(Vdd_meas(18,1:end), Vdd_meas(18,1:end)-Vref(18,1:end))

plot(VddDT4, polyval(p4(13,:), VddDT4))
plot(VddDT4, polyval(p4(17,:), VddDT4))
plot(VddDT4, polyval(p4(18,:), VddDT4))

hold off
title('DTMOS Line Regulation (4 K)')
ylabel('Vref [V]')
xlabel('Vdd [V]')
xlim([0.9 1.15])
ylim([0.58 0.6])
grid on
legend('PSR, measured', 'PSR, measured', 'Basic, measured', 'PSR, linear fit', 'PSR, linear fit', 'Basic, linear fit')




load('4K_PMOS.mat')

%PMOS
figure(11)
hold on
plot(Vdd_meas(29,:), Vdd_meas(29,:)-Vref(29,:))
plot(Vdd_meas(30,:), Vdd_meas(30,:)-Vref(30,:))
plot(Vdd_meas(34,:), Vdd_meas(34,:)-Vref(34,:))
hold off
title('PMOS Line Regulation (4 K)')
ylabel('Vref [V]')
xlabel('Vdd [V]')
xlim([0.95 1.15])
grid on
legend('PSR Architecture', 'PSR Architecture', 'Basic Architecture')

start_ind = 47;

%Perform the fit for PMOS
for j=[29, 30, 34]
    p4(j,:) = polyfit(Vdd_meas(j,start_ind:end), Vdd_meas(j,start_ind:end)-Vref(j,start_ind:end),1);
end

VddP4 = [Vdd_meas(29,start_ind), Vdd_meas(29,end)];

%PMOS
figure(12)
hold on

plot(Vdd_meas(29,1:end), Vdd_meas(29,1:end)-Vref(29,1:end))
plot(Vdd_meas(30,1:end), Vdd_meas(30,1:end)-Vref(30,1:end))
plot(Vdd_meas(34,1:end), Vdd_meas(34,1:end)-Vref(34,1:end))

plot(VddP4, polyval(p4(29,:), VddP4))
plot(VddP4, polyval(p4(30,:), VddP4))
plot(VddP4, polyval(p4(34,:), VddP4))

hold off
title('PMOS Line Regulation (4 K)')
ylabel('Vref [V]')
xlabel('Vdd [V]')
xlim([0.95 1.15])
ylim([0.67 0.71])
grid on
legend('PSR, measured', 'PSR, measured', 'Basic, measured', 'PSR, linear fit', 'PSR, linear fit', 'Basic, linear fit')

