clear all;
close all;

%Allocate data
Vref_comb_300 = NaN*zeros(34,501);
Vdd_meas_comb_300 = NaN*zeros(34,501);
Vref_comb_4 = NaN*zeros(34,251);
Vdd_meas_comb_4 = NaN*zeros(34,251);


%Load 300K data
load('300K_NMOS.mat')
Vref_comb_300([1 2 6], :) = Vref([1 2 6],:);
Vdd_meas_comb_300([1 2 6], :) = Vdd_meas([1 2 6],:);

%Measured Vref for PMOS and DTMOS is Vdd-referred
load('300K_PMOS.mat')
Vref_comb_300([29 30 34], :) = Vdd_meas([29 30 34],:)-Vref([29 30 34],:);
Vdd_meas_comb_300([29 30 34], :) = Vdd_meas([29 30 34],:);

load('300K_DTMOS.mat')
Vref_comb_300([13 17 18], :) = Vdd_meas([13 17 18],:)-Vref([13 17 18],:);
Vdd_meas_comb_300([13 17 18], :) = Vdd_meas([13 17 18],:);

%Load 4K data
load('4K_NMOS.mat')
Vref_comb_4([1 2 6], :) = Vref([1 2 6],:);
Vdd_meas_comb_4([1 2 6], :) = Vdd_meas([1 2 6],:);

%Measured Vref for PMOS and DTMOS is Vdd-referred
load('4K_PMOS.mat')
Vref_comb_4([29 30 34], 51:251) = Vdd_meas([29 30 34],:)-Vref([29 30 34],:);
Vdd_meas_comb_4([29 30 34], 51:251) = Vdd_meas([29 30 34],:);

load('4K_DTMOS.mat')
Vref_comb_4([13 17 18], :) = Vdd_meas([13 17 18],:)-Vref([13 17 18],:);
Vdd_meas_comb_4([13 17 18], :) = Vdd_meas([13 17 18],:);

clear Vref;
clear Vdd_meas;

%Manually remove points (except for last point before starting up) with startup issues (only happens at 4K)
%Everything below 0.475
ind4 = (Vref_comb_4<=0.475);
Vref_comb_4(ind4) = NaN;

%Manually remove two datapoints from PMOS
Vref_comb_4(29, [63,65,72,73]) = NaN;

%% NMOS 300 K
figure(1)
set(gcf,'units','points','position',[1000,300,450,250])
%set(gca,'fontweight','bold')

s1 = subplot(231);
hold on
h1 = plot(Vdd_meas_comb_300(1,:), Vref_comb_300(1,:), 'Color', [0 0.4470 0.7410]);  %psr1, 10.8
h2 = plot(Vdd_meas_comb_300(2,:), Vref_comb_300(2,:), 'Color', [0 0.4470 0.7410]);  %psr2, 11.2
h6 = plot(Vdd_meas_comb_300(6,:), Vref_comb_300(6,:), 'Color', [0.8500 0.3250 0.0980]);  %basic, 34.1
hold off
grid on

set(s1, 'XColor', 'k', 'YColor', 'k', 'GridColor', 'k')
xlim([0.8 1.15]); set(gca, 'xTick', [0.8 0.95 1.1]);
ylim([0.48 0.505])
ylabel('V_{ref} [V]');
set(gca,'fontweight','bold')
txttitle = 'NMOS, 300 K';
text(0.86, 0.507, txttitle, 'fontweight', 'bold');
%leg1 = legend([h1 h2], 'Prop.', 'Simp.');
%pos1 = [0.2 0.62 0.15 0.1];
%set(leg1, 'Position', pos1);
%legend boxoff


%Put values for line regulation in the plot
N300 = '34.1 mV/V';
N300psr1 = '10.8 mV/V';
N300psr2 = '11.2 mV/V';
text(0.84, 0.485, N300, 'fontweight', 'bold');
text(0.96, 0.49, N300psr1, 'fontweight', 'bold');
text(0.84, 0.503, N300psr2, 'fontweight', 'bold');

%% PMOS 300 K

s2 = subplot(232);
hold on
h29 = plot(Vdd_meas_comb_300(29,:), Vref_comb_300(29,:), 'Color', [0 0.4470 0.7410]);   %psr1, 11.5
h30 = plot(Vdd_meas_comb_300(30,:), Vref_comb_300(30,:), 'Color', [0 0.4470 0.7410]);   %psr2, 12.0
h34 = plot(Vdd_meas_comb_300(34,:), Vref_comb_300(34,:), 'Color', [0.8500 0.3250 0.0980]);   %basic, 29.1
hold off
grid on

set(s2, 'XColor', 'k', 'YColor', 'k', 'GridColor', 'k')
xlim([0.8 1.15]); set(gca, 'xTick', [0.8 0.95 1.1]);
ylim([0.607 0.632]);
set(gca,'fontweight','bold')

txttitle = 'PMOS, 300 K';
text(0.86, 0.634, txttitle, 'fontweight', 'bold');

%leg2 = legend([h29 h30], 'Prop.', 'Simp.');
%legend boxoff
%pos2 = [0.48 0.62 0.15 0.1];
%set(leg2, 'Position', pos2)

%Put values for line regulation in the plot
P300 = '29.1 mV/V';
P300psr1 = '11.5 mV/V';
P300psr2 = '12.0 mV/V';
text(0.91, 0.613, P300, 'fontweight', 'bold');
text(0.88, 0.623, P300psr1, 'fontweight', 'bold');
text(0.81, 0.631, P300psr2, 'fontweight', 'bold');

%% DTMOS 300 K

s3 = subplot(233);
hold on
h13 = plot(Vdd_meas_comb_300(13,:), Vref_comb_300(13,:), 'Color', [0 0.4470 0.7410]);   %psr1, 7.0
h17 = plot(Vdd_meas_comb_300(17,:), Vref_comb_300(17,:), 'Color', [0 0.4470 0.7410]);   %psr2, 5.7
h18 = plot(Vdd_meas_comb_300(18,:), Vref_comb_300(18,:), 'Color', [0.8500 0.3250 0.0980]);   %basic, 22.6
hold off
grid on

set(s3, 'XColor', 'k', 'YColor', 'k', 'GridColor', 'k')
xlim([0.8 1.15]); set(gca, 'xTick', [0.8 0.95 1.1]);
ylim([0.525 0.55]);
set(gca,'fontweight','bold')

txttitle = 'DTMOS, 300 K';
text(0.84, 0.552, txttitle, 'fontweight', 'bold');

%leg3 = legend([h13 h17], 'Prop.', 'Simp.');
%legend boxoff
%pos3 = [0.695 0.83 0.15 0.1];
%set(leg3, 'Position', pos3)


%Put values for line regulation in the plot
DT300 = '22.6 mV/V';
DT300psr1 = '7.0 mV/V';
DT300psr2 = '5.7 mV/V';
text(0.85, 0.545, DT300, 'fontweight', 'bold');
text(1, 0.534, DT300psr1, 'fontweight', 'bold');
text(1, 0.5415, DT300psr2, 'fontweight', 'bold');

%% NMOS 4 K

%NMOS
s4 = subplot(234);
hold on
h1_4 = plot(Vdd_meas_comb_4(1,:), Vref_comb_4(1,:), 'Color', [0 0.4470 0.7410]);    %psr1, -3.1
h2_4 = plot(Vdd_meas_comb_4(2,:), Vref_comb_4(2,:), 'Color', [0 0.4470 0.7410]);    %psr2, 6.7
h6_4 = plot(Vdd_meas_comb_4(6,:), Vref_comb_4(6,:), 'Color', [0.8500 0.3250 0.0980]);    %basic, 20.3
hold off
grid on

set(s4, 'XColor', 'k', 'YColor', 'k', 'GridColor', 'k')
xlabel('V_{dd} [V]'); xlim([0.8 1.15]); set(gca, 'xTick', [0.8 0.95 1.1]);
ylabel('V_{ref} [V]'); ylim([0.475 0.50]);
set(gca,'fontweight','bold')
txttitle = 'NMOS, 4.2 K';
text(0.88, 0.502, txttitle, 'fontweight', 'bold');
txt_sim = 'Simp.';
txt_prop = 'Prop.';

%leg4 = legend([h1_4 h2_4], 'Prop.', 'Simp.');
%legend boxoff
%pos4 = [0.13 0.36    0.15    0.1];
%set(leg4, 'Position', pos4)

%Put values for line regulation in the plot
N4 = [' 20.3' newline 'mV/V'];
N4psr1 = '-3.1 mV/V';
N4psr2 = '6.7 mV/V';
text(1.01, 0.4787, N4, 'fontweight', 'bold');
text(0.98, 0.487, N4psr1, 'fontweight', 'bold');
text(0.834, 0.497, N4psr2, 'fontweight', 'bold');

%% PMOS 4 K

%PMOS
s5 = subplot(235);
hold on
h29_4 = plot(Vdd_meas_comb_4(29,:), Vref_comb_4(29,:), 'Color', [0 0.4470 0.7410]); %psr1, 15.7
h30_4 = plot(Vdd_meas_comb_4(30,:), Vref_comb_4(30,:), 'Color', [0 0.4470 0.7410]); %psr2, 22.0
h34_4 = plot(Vdd_meas_comb_4(34,:), Vref_comb_4(34,:), 'Color', [0.8500 0.3250 0.0980]); %basic, 36.7
hold off
grid on

set(s5, 'XColor', 'k', 'YColor', 'k', 'GridColor', 'k')
xlabel('V_{dd} [V]'); xlim([0.8 1.15]); set(gca, 'xTick', [0.8 0.95 1.1]);
ylim([0.682 0.707]);
set(gca,'fontweight','bold')
txttitle = 'PMOS, 4.2 K';
text(0.86, 0.709, txttitle, 'fontweight', 'bold');
%leg5 = legend([h29_4 h30_4], 'Prop.', 'Simp.');
%legend boxoff
%pos5 = [0.415    0.36   0.15 0.1];
%set(leg5, 'Position', pos5)

%Put values for line regulation in the plot
P4 = '36.7 mV/V';
P4psr1 = [' 15.7' newline 'mV/V'];
P4psr2 = '11.0 mV/V';
text(1.002, 0.6839, P4, 'fontweight', 'bold');
text(1.016, 0.6968, P4psr1, 'fontweight', 'bold');
text(0.8075, 0.7041, P4psr2, 'fontweight', 'bold');

%% DTMOS 4 K

s6 = subplot(236);
hold on
h13_4 = plot(Vdd_meas_comb_4(13,:), Vref_comb_4(13,:), 'Color', [0 0.4470 0.7410]); %psr1, -1.3
h17_4 = plot(Vdd_meas_comb_4(17,:), Vref_comb_4(17,:), 'Color', [0 0.4470 0.7410]); %psr2, 14.4
h18_4 = plot(Vdd_meas_comb_4(18,:), Vref_comb_4(18,:), 'Color', [0.8500 0.3250 0.0980]); %basic, 24.6
hold off
grid on

set(s6, 'XColor', 'k', 'YColor', 'k', 'GridColor', 'k')
xlabel('V_{dd} [V]'); xlim([0.8 1.15]); set(gca, 'xTick', [0.8 0.95 1.1]);
ylim([0.58 0.605])
set(gca,'fontweight','bold')

txttitle = 'DTMOS, 4.2 K';
text(0.85, 0.607, txttitle, 'fontweight', 'bold');

%leg6 = legend([h13_4 h13_4], 'Prop.', 'Simp.');
%legend boxoff
%pos6 = [0.695    0.36    0.15 0.1];
%set(leg6, 'Position', pos6)

%Put values for line regulation in the plot
DT4 = [' 24.6' newline 'mV/V'];
DT4psr1 = '-1.3 mV/V';
DT4psr2 = '14.4 mV/V';
text(1.016, 0.5899, DT4, 'fontweight', 'bold');
text(0.9855, 0.5823, DT4psr1, 'fontweight', 'bold');
text(0.9609, 0.6002, DT4psr2, 'fontweight', 'bold');



%Set thicker lines
set([h1 h1_4 h2 h2_4 h6 h6_4 h13 h13_4 h17 h17_4 h18 h18_4 h29 h29_4 h30 h30_4 h34 h34_4 ],'LineWidth',2)