%Plot the power consumption for JSSC

clear all;
close all;

NMOS_PSR = [1:5 7:10]';
NMOS_BASIC = 6;

DTMOS_PSR = [13:17 19:20]';
DTMOS_BASIC = 18;

PMOS_PSR = [21:22 29:33]';
PMOS_BASIC = 34;

load('Current_Consumption.mat')

%Compute averages
NMOS_BASIC_avg = 1.1*Current(NMOS_BASIC, :);
NMOS_PSR_avg = 1.1*mean(Current(NMOS_PSR,:));

PMOS_BASIC_avg = 1.1*Current(PMOS_BASIC, :);
PMOS_PSR_avg = 1.1*mean(Current(PMOS_PSR,:));

DTMOS_BASIC_avg = 1.1*Current(DTMOS_BASIC, :);
DTMOS_PSR_avg = 1.1*mean(Current(DTMOS_PSR,:));

%Plot the averages
figure(1)
hold on
h1 = plot(Temp, NMOS_BASIC_avg*1e6,  '-o');
h2 = plot(Temp, NMOS_PSR_avg*1e6,    '-o');
h3 = plot(Temp, PMOS_BASIC_avg*1e6, '-o');
h4 = plot(Temp, PMOS_PSR_avg*1e6,   '-o');
h5 = plot(Temp, DTMOS_BASIC_avg*1e6,  '-o');
h6 = plot(Temp, DTMOS_PSR_avg*1e6,    '-o');
hold off
grid on
xlabel('Temperature [K]')
ylabel('Power Consumption [\mu{W}]')
ylim([0 14])

set([h1 h2], 'Color',[0 0.447 0.741])
set([h3 h4], 'Color', [0.85 0.325 0.098])
set([h5 h6], 'Color', [0.466 0.674 0.188])
set([h1 h2 h3 h4 h5 h6], 'LineWidth', 1.8)

width=420;
height=250;
set(gcf,'units','points','position',[0,0,width,height])
set(gca,'fontweight','bold','fontsize',13)
set(gca, 'XColor', 'k', 'YColor', 'k', 'GridColor', 'k')


%Place markers for basic and psr architectures

hold on
a=10; % horizontal radius
b=1.2; % vertical radius
x0=250; % x0,y0 ellipse centre coordinates
y0=6.85;
t=-pi:0.01:pi;
x=x0+a*cos(t);
y=y0+b*sin(t);
ct = plot(x,y,'Color',[0 0 0]);
set(ct, 'linewidth', 2);
hold off

hold on
a=10; % horizontal radius
b=1.2; % vertical radius
x0=250; % x0,y0 ellipse centre coordinates
y0=10.4;
t=-pi:0.01:pi;
x=x0+a*cos(t);
y=y0+b*sin(t);
pt = plot(x,y,'Color',[0 0 0]);
set(pt, 'LineWidth', 2)
hold off

txt1 = 'Simplified';
txt2 = 'Proposed';
text(230, 5, txt1, 'fontweight', 'bold', 'fontsize', 13)
text(200, 12.4, txt2, 'fontweight', 'bold', 'fontsize', 13)

%Legend must be at the end
hleg = legend([h1 h3 h5], 'NMOS', 'PMOS', 'DTMOS');
set(hleg, 'Location', 'northwest')
legend boxoff
