clear all;
close all;

%bare: w/o DEM
%full: w/ DEM

%Select/average the datapoints for the DEM plots
[T, Vref_bare, ~, ~, Vref_full] = get_data_2();

%Allocate space
Vref_bare_fo = NaN*zeros(16, 297);
Vref_full_fo = NaN*zeros(16, 297);

%Define the T-axis for which we want to get the interpolated values
Temp = [4.27 5:300];


%Organize data based on the temperature (lowT-highT)
for j=1:16
    %Order temperatre
    [T(j,:), order] = sort(T(j,:));
    
    %Order data based on temperature
    Vref_bare(j,:) = Vref_bare(j,order);
    Vref_full(j,:) = Vref_full(j,order);
    
    %Perform the interpolation
    Vref_bare_fo(j,:) = first_order(T(j,:), Vref_bare(j,:), Temp);
    Vref_full_fo(j,:) = first_order(T(j,:), Vref_full(j,:), Temp);
    
end

%Compute mu and sigma
Vref_bare_mu = mean(Vref_bare_fo, 'omitnan');
Vref_bare_std = std(Vref_bare_fo, 'omitnan');

Vref_full_mu = mean(Vref_full_fo, 'omitnan');
Vref_full_std = std(Vref_full_fo, 'omitnan');

%Compute mu+/- 3sigma 
Vref_bare_std_p = Vref_bare_mu + 3*Vref_bare_std;
Vref_bare_std_n = Vref_bare_mu - 3*Vref_bare_std;

Vref_full_std_p = Vref_full_mu + 3*Vref_full_std;
Vref_full_std_n = Vref_full_mu - 3*Vref_full_std;

%%
%Apply the trimming

%---------------------------Set before running-----------------------------
Vref_trim = 0.5005;
T_trim = 150;
%--------------------------------------------------------------------------

%Find in which interval the specified T_trim falls
%Assume the trimming temperature is an integer!!!
for m=1:length(Temp) %All T-points
    if (T_trim == Temp(m))
       ind = m;
       break;
    end
end

%Find the required gain(or scaling)
gain_bare = Vref_trim./Vref_bare_fo(:,ind);
gain_full = Vref_trim./Vref_full_fo(:,ind);

%Data allocation
Vref_bare_fo_trim = zeros(16, length(Temp));
Vref_full_fo_trim = zeros(16, length(Temp));

Vref_bare_trim = NaN*zeros(16, 12);
Vref_full_trim = NaN*zeros(16, 12);

%Perform the scaling of the entire curve
for j=1:16
    
   %For calculation of the mu/sigma
   Vref_bare_fo_trim(j,:) = gain_bare(j,1)*Vref_bare_fo(j,:); 
   Vref_full_fo_trim(j,:) = gain_full(j,1)*Vref_full_fo(j,:); 
   
   %For plotting purposes
   Vref_bare_trim(j,:) = gain_bare(j,1)*Vref_bare(j,:);
   Vref_full_trim(j,:) = gain_full(j,1)*Vref_full(j,:);
end

%Compute mu, sigma, and mu+/-3sigma after trimming
Vref_bare_mu_trim = mean(Vref_bare_fo_trim, 'omitnan');
Vref_full_mu_trim = mean(Vref_full_fo_trim, 'omitnan');

Vref_bare_std_trim = std(Vref_bare_fo_trim, 'omitnan');
Vref_full_std_trim = std(Vref_full_fo_trim, 'omitnan');

Vref_bare_3sigmap_trim = Vref_bare_mu_trim + 3*Vref_bare_std_trim;
Vref_bare_3sigman_trim = Vref_bare_mu_trim - 3*Vref_bare_std_trim;
Vref_full_3sigmap_trim = Vref_full_mu_trim + 3*Vref_full_std_trim;
Vref_full_3sigman_trim = Vref_full_mu_trim - 3*Vref_full_std_trim;

