%Job van Staveren, 17-02-2022
clear all;
close all;

load('DEM_data_NMOS.mat')

%Plot bare data (no compensation)
figure(1)
hold on
for j=1:16
   plot(T(j,:), Vref_bare(j,:), '-o', 'Color', [0.9290 0.6940 0.1250])  
end

%Plot mean
plot(Temp, Vref_bare_mu, 'Color', [0 0.4470 0.7410], 'LineWidth',3)

%Plot +/-3sigma
plot(Temp, Vref_bare_mu+3*Vref_bare_std,       'Color', [0.8500 0.3250 0.0980], 'LineWidth',3);
plot(Temp, Vref_bare_mu-3*Vref_bare_std,       'Color', [0.8500 0.3250 0.0980], 'LineWidth',3);

hold off

%Labels/limits
ylabel('V_{ref} [V]')
xlabel('Temperature [K]')
ylim([0.46 0.54])

grid on
width=270;
height=230;
set(gcf,'units','points','position',[100,300,width,height])
set(gca,'fontweight','bold','fontsize',13)
set(gca, 'XColor', 'k', 'YColor', 'k', 'GridColor', 'k')

%Plot dummies for legend
hold on
h1 = plot(0, 1, 'Color', [0 0.4470 0.7410], 'LineWidth', 3);
h2 = plot(0, 1, 'Color', [0.8500 0.3250 0.0980], 'LineWidth', 3);
hold off
leg1 = legend([h1 h2], 'Average', '+/- 3{\sigma}');
set(leg1,'Position',[0.5925 0.7854 0.3138 0.1449]);
legend boxoff

txt1 = 'TC = 255 ppm/K';
txt2 = '3\sigma = 5.1%';
txt3 = '16 samples';
txt4 = ['w/o DEM',sprintf('\n'),'w/o trim'];
text(130, 0.473, txt1, 'fontweight', 'bold', 'fontsize', 13)
text(130, 0.465, txt2, 'fontweight', 'bold', 'fontsize', 13)
text(130, 0.481, txt3, 'fontweight', 'bold', 'fontsize', 13)
text(45, 0.533, txt4, 'fontweight', 'bold', 'fontsize', 13)


%Plot the trimmed bare data
figure(2)
hold on
for j=1:16
   plot(T(j,:), Vref_bare_trim(j,:), '-o', 'Color', [0.9290 0.6940 0.1250])  
end

%Plot mean
plot(Temp, Vref_bare_mu_trim, 'Color', [0 0.4470 0.7410], 'LineWidth',3)

%Plot +/-3sigma
plot(Temp, Vref_bare_mu_trim+3*Vref_bare_std_trim,       'Color', [0.8500 0.3250 0.0980], 'LineWidth',3);
plot(Temp, Vref_bare_mu_trim-3*Vref_bare_std_trim,       'Color', [0.8500 0.3250 0.0980], 'LineWidth',3);

hold off

%Labels/limits
ylabel('V_{ref} [V]')
xlabel('Temperature [K]')
ylim([0.46 0.54])

grid on
width=270;
height=230;
set(gcf,'units','points','position',[400,300,width,height])
set(gca,'fontweight','bold','fontsize',13)
set(gca, 'XColor', 'k', 'YColor', 'k', 'GridColor', 'k')

%Plot dummies for legend
hold on
h1 = plot(0, 1, 'Color', [0 0.4470 0.7410], 'LineWidth', 3);
h2 = plot(0, 1, 'Color', [0.8500 0.3250 0.0980], 'LineWidth', 3);
hold off

leg1 = legend([h1 h2], 'Average', '+/- 3{\sigma}');
set(leg1,'Position',[0.5925 0.7854 0.3138 0.1449]);
legend boxoff

txt1 = 'TC = 218 ppm/K';
txt2 = '3\sigma = 4.0%';
txt3 = '16 samples';
txt4 = ['w/o DEM',sprintf('\n'),'w/ trim'];
text(130, 0.473, txt1, 'fontweight', 'bold', 'fontsize', 13)
text(130, 0.465, txt2, 'fontweight', 'bold', 'fontsize', 13)
text(130, 0.481, txt3, 'fontweight', 'bold', 'fontsize', 13)
text(6.5, 0.533, txt4, 'fontweight', 'bold', 'fontsize', 13)



%Plot the untrimmed DEM-data
figure(3)
hold on
for j=1:16
   plot(T(j,:), Vref_full(j,:), '-o', 'Color', [0.9290 0.6940 0.1250])  
end

%Plot mean
plot(Temp, Vref_full_mu, 'Color', [0 0.4470 0.7410], 'LineWidth',3)

%Plot +/-3sigma
plot(Temp, Vref_full_mu+3*Vref_full_std,       'Color', [0.8500 0.3250 0.0980], 'LineWidth',3);
plot(Temp, Vref_full_mu-3*Vref_full_std,       'Color', [0.8500 0.3250 0.0980], 'LineWidth',3);

hold off

%Labels/limits
ylabel('V_{ref} [V]')
xlabel('Temperature [K]')
ylim([0.46 0.54])

grid on
width=270;
height=230;
set(gcf,'units','points','position',[700,300,width,height])
set(gca,'fontweight','bold','fontsize',13)
set(gca, 'XColor', 'k', 'YColor', 'k', 'GridColor', 'k')

%Plot dummies for legend
hold on
h1 = plot(0, 1, 'Color', [0 0.4470 0.7410], 'LineWidth', 3);
h2 = plot(0, 1, 'Color', [0.8500 0.3250 0.0980], 'LineWidth', 3);
hold off
leg1 = legend([h1 h2], 'Average', '+/- 3{\sigma}');
set(leg1,'Position',[0.5925 0.7854 0.3138 0.1449]);
legend boxoff

txt1 = 'TC = 138 ppm/K';
txt2 = '3\sigma = 1.6%';
txt3 = '16 samples';
txt4 = ['w/ DEM',sprintf('\n'),'w/o trim'];
text(130, 0.473, txt1, 'fontweight', 'bold', 'fontsize', 13)
text(130, 0.465, txt2, 'fontweight', 'bold', 'fontsize', 13)
text(130, 0.481, txt3, 'fontweight', 'bold', 'fontsize', 13)
text(6.5, 0.533, txt4, 'fontweight', 'bold', 'fontsize', 13)


%Plot the trimmed DEM data
figure(4)
hold on
for j=1:16
   plot(T(j,:), Vref_full_trim(j,:), '-o', 'Color', [0.9290 0.6940 0.1250])  
end

%Plot mean
plot(Temp, Vref_full_mu_trim, 'Color', [0 0.4470 0.7410], 'LineWidth',3)

%Plot +/-3sigma
plot(Temp, Vref_full_mu_trim+3*Vref_full_std_trim,       'Color', [0.8500 0.3250 0.0980], 'LineWidth',3);
plot(Temp, Vref_full_mu_trim-3*Vref_full_std_trim,       'Color', [0.8500 0.3250 0.0980], 'LineWidth',3);

hold off

%Labels/limits
ylabel('V_{ref} [V]')
xlabel('Temperature [K]')
ylim([0.46 0.54])

grid on
width=270;
height=230;
set(gcf,'units','points','position',[1000,300,width,height])
set(gca,'fontweight','bold','fontsize',13)
set(gca, 'XColor', 'k', 'YColor', 'k', 'GridColor', 'k')

%Plot dummies for legend
hold on
h1 = plot(0, 1, 'Color', [0 0.4470 0.7410], 'LineWidth', 3);
h2 = plot(0, 1, 'Color', [0.8500 0.3250 0.0980], 'LineWidth', 3);
hold off

leg1 = legend([h1 h2], 'Average', '+/- 3{\sigma}');
set(leg1,'Position',[0.5925 0.7854 0.3138 0.1449]);
legend boxoff

txt1 = 'TC = 111 ppm/K';
txt2 = '3\sigma = 1.2%';
txt3 = '16 samples';
txt4 = ['w/ DEM',sprintf('\n'),'w/ trim'];
text(130, 0.473, txt1, 'fontweight', 'bold', 'fontsize', 13)
text(130, 0.465, txt2, 'fontweight', 'bold', 'fontsize', 13)
text(130, 0.481, txt3, 'fontweight', 'bold', 'fontsize', 13)
text(6.5, 0.533, txt4, 'fontweight', 'bold', 'fontsize', 13)